@@ -13,6 +13,15 @@ from .validation import validate, is_spec, ValidationError
 from .utils import normalize_keys
 
 
+# global configuration object. When `configure` is called, the config is placed
+# here as well as returned.
+_CONFIG = attrs()
+
+
+def CONFIG():
+  return _CONFIG
+
+
 def load_config(path, relative_to_caller=False):
   """Load a config module as a dict
 
@@ -162,7 +171,10 @@ def configure(args=None, config_path=None, spec_path=None):
     spec   = load_spec(spec_path)
     config = validate(spec, config)
 
-  return attrs.from_dict(config)
+  # load config into global object
+  global _CONFIG
+  _CONFIG = attrs.from_dict(config)
+  return CONFIG()
 
 
 def _eat_command_line_arguments(args=None):
